@@ -2,7 +2,7 @@
 These meta-datasources operate on :class:`revscoring.Datasource`'s that
 return `list`'s and `tuple`'s
 
-.. autoclass:: revscoring.datasources.meta.index
+.. autoclass:: revscoring.datasources.meta.indexable.index
 
 """
 from ..datasource import Datasource
@@ -21,6 +21,7 @@ class index(Datasource):
         name : `str`
             A name for the new datasource.
     """
+
     def __init__(self, i, datasources, default=NotImplemented, name=None):
         name = self._format_name(name, [i, default])
         self.i = int(i)
