@@ -1,7 +1,8 @@
-from . import datasources
-from ...datasources import revision_oriented
-from ...dependencies import DependentSet
+from revscoring.datasources import revision_oriented
+from revscoring.dependencies import DependentSet
+
 from ..meta import aggregators
+from . import datasources
 
 name = "bytes.revision"
 
@@ -26,6 +27,7 @@ class Revision(DependentSet):
             parent (aka "previous") revision of the page.
             """
 
+
 revision = Revision(name,
                     datasources.Revision(name, revision_oriented.revision))
 """
